@@ -9,6 +9,7 @@
 #' @param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.
 #' @param col.bar A \code{character} string specifying the color of the bars to generate the graph showing the relative abundances of the pollen types. The \code{color} argument will be \code{#E69F00} by default, but any color may be selected.
 #' @param type.plot A \code{character} string specifying the type of plot selected to show the plot showing the relative abundance of the pollen types. The implemented types that may be used are: \code{static} generates a static \strong{ggplot} object and \code{dynamic} generates a dynamic \strong{plotly} object.
+#' @param result A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"plot"} and \code{"table"}. The argument \code{result} will be \code{"plot"} by default.
 #' @param export.plot A \code{logical} value specifying if a plot saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} or \emph{png} file (according to the \code{export.format} argument) will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. This argument is applicable only for \code{"static"} plots. The \code{export.plot} will be \code{FALSE} by default.
 #' @param export.format A \code{character} string specifying the format selected to save the plot showing the relative abundance of the pollen types. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. This argument is applicable only for \code{"static"} plots. The \code{export.format} will be \code{"pdf"} by default.
 #' @param exclude A \code{character} string vector with the names of the pollen types to be excluded from the plot.
@@ -18,9 +19,9 @@
 #' Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
 #' @return This function returns different results:\cr
 #' \cr
-#' \code{plot} in the active graphics window displaying the pollen calendar generated by the user. This \code{plot} may be included in an object by assignment operators.\cr
+#' \code{plot} in the active graphics window displaying the pollen calendar generated by the user when \code{result = "plot"}. This \code{plot} may be included in an object by assignment operators.\cr
 #' \cr
-#' \code{data.frame} including the yearly average pollen amounts for each pollen types used to generate the pollen of the relative abundance. This \code{data.frame} will be included in an object named \code{annual.sum.data}.\cr
+#' \code{data.frame} including the yearly average pollen amounts for each pollen types used to generate the pollen of the relative abundance when \code{result = "table"}. This \code{data.frame} will be included in an object named \code{annual.sum.data}.\cr
 #' \cr
 #' If \code{export.plot = FALSE} graphical results will only be displayed in the active graphics window as \strong{ggplot} graph. Additional characteristics may be incorporated to the plot by \code{\link[ggplot2]{ggplot}} syntax (see \pkg{ggplot2} package).\cr
 #' \cr
@@ -31,11 +32,11 @@
 #' If \code{type.plot = dynamic} graphical results will be displayed in the active Viewer window as \strong{plotly} graph. Additional characteristics may be incorporated to the plot by \code{\link[plotly]{plotly}} syntax (see \pkg{plotly} package).
 #' @references Rojo, J., Rapp, A., Lara, B., Sabariego, S., Fernandez_Gonzalez, F. and Perez_Badia, R., 2016. Characterisation of the airborne pollen spectrum in Guadalajara (central Spain) and estimation of the potential allergy risk. \emph{Environmental Monitoring and Assessment}, 188(3), p.130.
 #' @seealso \code{\link{interpollen}}
-#' @examples data("munich")
-#' @examples iplot_abundance (munich, interpolation = FALSE, export.plot = FALSE)
+#' @examples data("munich_pollen")
+#' @examples iplot_abundance (munich_pollen, interpolation = FALSE, export.plot = FALSE)
 #' @importFrom utils data
 #' @importFrom lubridate is.POSIXt
-#' @importFrom plyr ddply
+#' @importFrom dplyr group_by summarise_all
 #' @importFrom plotly ggplotly
 #' @importFrom ggplot2 aes coord_flip element_blank element_text geom_bar geom_errorbar ggplot labs position_dodge theme theme_classic
 #' @importFrom graphics plot
@@ -51,6 +52,7 @@ iplot_abundance <- function (data,
                              int.method = "lineal",
                              col.bar = "#E69F00",
                              type.plot = "static",
+                             result = "plot",
                              export.plot = FALSE,
                              export.format = "pdf",
                              exclude = NULL,
@@ -60,6 +62,7 @@ iplot_abundance <- function (data,
 
   if(export.plot == TRUE){ifelse(!dir.exists(file.path("plot_AeRobiology")), dir.create(file.path("plot_AeRobiology")), FALSE)}
 
+  data<-data.frame(data)
   if(class(data) != "data.frame") stop ("Please include a data.frame: first column with date, and the rest with pollen types")
 
   if(class(n.types) != "numeric") stop ("Please include only numeric values for 'n.types' argument indicating the number of pollen types which will be displayed")
@@ -76,6 +79,8 @@ iplot_abundance <- function (data,
 
   if(type.plot != "static" & type.plot != "dynamic") stop ("Please type.plot only accept values: 'static' or 'dynamic'")
 
+  if(result != "plot" & result != "table") stop ("Please result only accept values: 'plot' or 'table'")
+
   if(class(export.plot) != "logical") stop ("Please include only logical values for export.plot argument")
 
   if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")
@@ -88,10 +93,16 @@ iplot_abundance <- function (data,
 if(interpolation == TRUE){data <- interpollen(data, method = int.method, plot = FALSE)}
 
 #############################################    SELECT ABUNDANT TYPES       #############################
-  annual.sum.data<-data.frame()
+  #annual.sum.data<-data.frame()
 data <- data.frame(date = data[ ,1], year = as.numeric(strftime(data[ ,1], "%Y")), data[ ,-1])
 
-types <- ddply(data[ ,-1], "year", function(x) colSums(x[-1], na.rm = T)) [-1] %>%
+#types <- ddply(data[ ,-1], "year", function(x) colSums(x[-1], na.rm = T)) [-1] %>%
+#  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
+#  names(.) %>%
+#  .[1:n.types]
+types <- data.frame(data[ ,-1] %>%
+                      group_by(year) %>%
+                      summarise_all(sum, na.rm = TRUE))[-1] %>%
   apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
   names(.) %>%
   .[1:n.types]
@@ -108,7 +119,11 @@ data <- data[which(as.numeric(strftime(data[ ,1], "%Y")) >= y.start & as.numeric
 
 ##############################################################################
 
-sum.data <- ddply(data, c("year"), function(x) colSums(x[ ,-which(colnames(x) %in% c("date", "year"))], na.rm = T))
+#sum.data <- ddply(data, c("year"), function(x) colSums(x[ ,-which(colnames(x) %in% c("date", "year"))], na.rm = T))
+sum.data <- data.frame(data[ ,-1] %>%
+                      group_by(year) %>%
+                      summarise_all(sum, na.rm = TRUE))
+
 sum.data$Total <- apply(sum.data[ ,-which(colnames(sum.data) %in% c("year"))], 1, sum, na.rm = T)
 
 perc.df <- sum.data[ ,-which(colnames(sum.data) == "year")]
@@ -153,9 +168,9 @@ if(export.plot == TRUE & type.plot == "static" & export.format == "pdf") {
   dev.off()
 }
 
-annual.sum.data <<- sum.data
+if (result == "plot" & type.plot == "static") {return(plot.abundance)}
+if (result == "plot" & type.plot == "dynamic") {return(ggplotly(plot.abundance))}
 
-if (type.plot == "static") {return(plot.abundance)}
-if (type.plot == "dynamic") {return(ggplotly(plot.abundance))}
+if (result == "table") {return(sum.data)}
 
 }
